aboutsummaryrefslogtreecommitdiff
path: root/src/core/or/circuit_st.h
diff options
context:
space:
mode:
authorGeorge Kadianakis <desnacked@riseup.net>2019-03-13 15:24:04 +0200
committerteor <teor@torproject.org>2019-03-22 09:23:05 +1000
commit57291602532bfe55060668293130b0aac1fd702e (patch)
tree14d78126b270adf23a0e5ead007b7cf84bfcb048 /src/core/or/circuit_st.h
parent846d379b50b4f4790a9fe2ec88746748e0fab2b7 (diff)
downloadtor-57291602532bfe55060668293130b0aac1fd702e.tar.gz
tor-57291602532bfe55060668293130b0aac1fd702e.zip
circpad: Rename circpad_machine_state_t to circpad_machine_runtime_t.
The name of circpad_machine_state_t was very confusing since it was conflicting with circpad_state_t and circpad_circuit_state_t. Right now here is the current meaning of these structs: circpad_state_t -> A state of the state machine. circpad_machine_runtime_t -> The current mutable runtime info of the state machine. circpad_circuit_state_t -> Circuit conditions based on which we should apply a machine to the circuit
Diffstat (limited to 'src/core/or/circuit_st.h')
-rw-r--r--src/core/or/circuit_st.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/core/or/circuit_st.h b/src/core/or/circuit_st.h
index af343f082e..c972b99318 100644
--- a/src/core/or/circuit_st.h
+++ b/src/core/or/circuit_st.h
@@ -13,7 +13,7 @@
struct hs_token_t;
struct circpad_machine_spec_t;
-struct circpad_machine_state_t;
+struct circpad_machine_runtime_t;
/** Number of padding state machines on a circuit. */
#define CIRCPAD_MAX_MACHINES (2)
@@ -193,8 +193,8 @@ struct circuit_t {
* and we can have up to CIRCPAD_MAX_MACHINES such machines. */
const struct circpad_machine_spec_t *padding_machine[CIRCPAD_MAX_MACHINES];
/** Adaptive Padding machine info for above machines. This is the
* per-circuit mutable information, such as the current state and
* histogram token counts. Some of it is optional (aka NULL).
* If a machine is being shut down, these indexes can be NULL
* without the corresponding padding_machine being NULL, while we
@@ -202,7 +202,7 @@ struct circuit_t {
*
* Each element of this array corresponds to a different padding machine,
* and we can have up to CIRCPAD_MAX_MACHINES such machines. */
- struct circpad_machine_state_t *padding_info[CIRCPAD_MAX_MACHINES];
+ struct circpad_machine_runtime_t *padding_info[CIRCPAD_MAX_MACHINES];
};
#endif
@@ -193,8 +193,8 @@ struct circuit_t {
* and we can have up to CIRCPAD_MAX_MACHINES such machines. */
const struct circpad_machine_spec_t *padding_machine[CIRCPAD_MAX_MACHINES];
- /** Adaptive Padding machine info for above machines. This is the
- * per-circuit mutable information, such as the current state and
+ /** Adaptive Padding machine runtime info for above machines. This is
+ * the per-circuit mutable information, such as the current state and
* histogram token counts. Some of it is optional (aka NULL).
* If a machine is being shut down, these indexes can be NULL